@@ -33,7 +33,7 @@ class TSLS_Regimes(BaseTSLS, REGI.Regimes_Frame):
                    endogenous variable
     q            : array
                    Two dimensional array with n rows and one column for each
-                   external exogenous variable to use as instruments (note: 
+                   external exogenous variable to use as instruments (note:
                    this should not contain any variables from x)
     regimes      : list
                    List of n values with the mapping of each
@@ -57,11 +57,11 @@ class TSLS_Regimes(BaseTSLS, REGI.Regimes_Frame):
     robust       : string
                    If 'white', then a White consistent estimator of the
                    variance-covariance matrix is given.
-                   If 'hac', then a HAC consistent estimator of the 
+                   If 'hac', then a HAC consistent estimator of the
                    variance-covariance matrix is given.
                    If 'ogmm', then Optimal GMM is used to estimate
                    betas and the variance-covariance matrix.
-                   Default set to None. 
+                   Default set to None.
     gwk          : pysal W object
                    Kernel spatial weights needed for HAC estimation. Note:
                    matrix must have ones along the main diagonal.
@@ -114,7 +114,7 @@ class TSLS_Regimes(BaseTSLS, REGI.Regimes_Frame):
                    (see 'multi' below for details)
     q            : array
                    Two dimensional array with n rows and one column for each
-                   external exogenous variable used as instruments 
+                   external exogenous variable used as instruments
                    Only available in dictionary 'multi' when multiple regressions
                    (see 'multi' below for details)
     vm           : array
@@ -188,7 +188,7 @@ class TSLS_Regimes(BaseTSLS, REGI.Regimes_Frame):
     This is the DBF associated with the NAT shapefile.  Note that
     libpysal.io.open() also reads data in CSV format; since the actual class
     requires data to be passed in as numpy arrays, the user can read their
-    data in using any method.  
+    data in using any method.
 
     >>> nat = load_example('Natregimes')
     >>> db = libpysal.io.open(nat.get_path('natregimes.dbf'), 'r')
@@ -225,7 +225,7 @@ class TSLS_Regimes(BaseTSLS, REGI.Regimes_Frame):
     >>> q_var = ['FP89']
     >>> q = np.array([db.by_col(name) for name in q_var]).T
 
-    The different regimes in this data are given according to the North and 
+    The different regimes in this data are given according to the North and
     South dummy (SOUTH).
 
     >>> r_var = 'SOUTH'
@@ -271,20 +271,41 @@ class TSLS_Regimes(BaseTSLS, REGI.Regimes_Frame):
 
     """
 
-    def __init__(self, y, x, yend, q, regimes,
-                 w=None, robust=None, gwk=None, sig2n_k=True,
-                 spat_diag=False, vm=False, constant_regi='many',
-                 cols2regi='all', regime_err_sep=True, name_y=None, name_x=None,
-                 cores=False, name_yend=None, name_q=None, name_regimes=None,
-                 name_w=None, name_gwk=None, name_ds=None, summ=True):
+    def __init__(
+        self,
+        y,
+        x,
+        yend,
+        q,
+        regimes,
+        w=None,
+        robust=None,
+        gwk=None,
+        sig2n_k=True,
+        spat_diag=False,
+        vm=False,
+        constant_regi="many",
+        cols2regi="all",
+        regime_err_sep=True,
+        name_y=None,
+        name_x=None,
+        cores=False,
+        name_yend=None,
+        name_q=None,
+        name_regimes=None,
+        name_w=None,
+        name_gwk=None,
+        name_ds=None,
+        summ=True,
+    ):
 
         n = USER.check_arrays(y, x)
         y = USER.check_y(y, n)
         USER.check_weights(w, y)
         USER.check_robust(robust, gwk)
         USER.check_spat_diag(spat_diag, w)
-        x_constant,name_x,warn = USER.check_constant(x,name_x,just_rem=True)
-        set_warn(self,warn)
+        x_constant, name_x, warn = USER.check_constant(x, name_x, just_rem=True)
+        set_warn(self, warn)
         name_x = USER.set_name_x(name_x, x_constant, constant=True)
         self.constant_regi = constant_regi
         self.cols2regi = cols2regi
@@ -298,46 +319,96 @@ class TSLS_Regimes(BaseTSLS, REGI.Regimes_Frame):
         self.name_x_r = USER.set_name_x(name_x, x_constant) + name_yend
         self.n = n
         cols2regi = REGI.check_cols2regi(
-            constant_regi, cols2regi, x_constant, yend=yend, add_cons=False)
+            constant_regi, cols2regi, x_constant, yend=yend, add_cons=False
+        )
         self.regimes_set = REGI._get_regimes_set(regimes)
         self.regimes = regimes
         USER.check_regimes(self.regimes_set, self.n, x_constant.shape[1])
-        if regime_err_sep == True and robust == 'hac':
+        if regime_err_sep == True and robust == "hac":
             set_warn(
-                self, "Error by regimes is incompatible with HAC estimation for 2SLS models. Hence, the error by regimes has been disabled for this model.")
+                self,
+                "Error by regimes is incompatible with HAC estimation for 2SLS models. Hence, the error by regimes has been disabled for this model.",
+            )
             regime_err_sep = False
         self.regime_err_sep = regime_err_sep
-        if regime_err_sep == True and set(cols2regi) == set([True]) and constant_regi == 'many':
+        if (
+            regime_err_sep == True
+            and set(cols2regi) == set([True])
+            and constant_regi == "many"
+        ):
             self.y = y
             regi_ids = dict(
-                (r, list(np.where(np.array(regimes) == r)[0])) for r in self.regimes_set)
-            self._tsls_regimes_multi(x_constant, yend, q, w, regi_ids, cores,
-                                     gwk, sig2n_k, robust, spat_diag, vm, name_x, name_yend, name_q)
+                (r, list(np.where(np.array(regimes) == r)[0])) for r in self.regimes_set
+            )
+            self._tsls_regimes_multi(
+                x_constant,
+                yend,
+                q,
+                w,
+                regi_ids,
+                cores,
+                gwk,
+                sig2n_k,
+                robust,
+                spat_diag,
+                vm,
+                name_x,
+                name_yend,
+                name_q,
+            )
         else:
-            q, self.name_q = REGI.Regimes_Frame.__init__(self, q,
-                                                         regimes, constant_regi=None, cols2regi='all', names=name_q)
-            x, self.name_x = REGI.Regimes_Frame.__init__(self, x_constant,
-                                                         regimes, constant_regi, cols2regi=cols2regi, names=name_x)
-            yend, self.name_yend = REGI.Regimes_Frame.__init__(self, yend,
-                                                               regimes, constant_regi=None,
-                                                               cols2regi=cols2regi, yend=True, names=name_yend)
+            q, self.name_q = REGI.Regimes_Frame.__init__(
+                self, q, regimes, constant_regi=None, cols2regi="all", names=name_q
+            )
+            x, self.name_x = REGI.Regimes_Frame.__init__(
+                self,
+                x_constant,
+                regimes,
+                constant_regi,
+                cols2regi=cols2regi,
+                names=name_x,
+            )
+            yend, self.name_yend = REGI.Regimes_Frame.__init__(
+                self,
+                yend,
+                regimes,
+                constant_regi=None,
+                cols2regi=cols2regi,
+                yend=True,
+                names=name_yend,
+            )
             if regime_err_sep == True and robust == None:
-                robust = 'white'
-            BaseTSLS.__init__(self, y=y, x=x, yend=yend, q=q,
-                              robust=robust, gwk=gwk, sig2n_k=sig2n_k)
+                robust = "white"
+            BaseTSLS.__init__(
+                self, y=y, x=x, yend=yend, q=q, robust=robust, gwk=gwk, sig2n_k=sig2n_k
+            )
             self.title = "TWO STAGE LEAST SQUARES - REGIMES"
-            if robust == 'ogmm':
+            if robust == "ogmm":
                 _optimal_weight(self, sig2n_k)
             self.name_z = self.name_x + self.name_yend
             self.name_h = USER.set_name_h(self.name_x, self.name_q)
             self.chow = REGI.Chow(self)
             self.robust = USER.set_robust(robust)
             if summ:
-                SUMMARY.TSLS(
-                    reg=self, vm=vm, w=w, spat_diag=spat_diag, regimes=True)
+                SUMMARY.TSLS(reg=self, vm=vm, w=w, spat_diag=spat_diag, regimes=True)
 
-    def _tsls_regimes_multi(self, x, yend, q, w, regi_ids, cores,
-                            gwk, sig2n_k, robust, spat_diag, vm, name_x, name_yend, name_q):
+    def _tsls_regimes_multi(
+        self,
+        x,
+        yend,
+        q,
+        w,
+        regi_ids,
+        cores,
+        gwk,
+        sig2n_k,
+        robust,
+        spat_diag,
+        vm,
+        name_x,
+        name_yend,
+        name_q,
+    ):
         results_p = {}
         """
         for r in self.regimes_set:
@@ -349,16 +420,53 @@ class TSLS_Regimes(BaseTSLS, REGI.Regimes_Frame):
                 results_p[r] = pool.apply_async(_work,args=(self.y,x,w,regi_ids,r,yend,q,robust,sig2n_k,self.name_ds,self.name_y,name_x,name_yend,name_q,self.name_w,self.name_regimes))
                 is_win = False
         """
-        x_constant,name_x = REGI.check_const_regi(self,x,name_x,regi_ids)
+        x_constant, name_x = REGI.check_const_regi(self, x, name_x, regi_ids)
         self.name_x_r = name_x
         for r in self.regimes_set:
             if cores:
                 pool = mp.Pool(None)
-                results_p[r] = pool.apply_async(_work, args=(
-                    self.y, x_constant, w, regi_ids, r, yend, q, robust, sig2n_k, self.name_ds, self.name_y, name_x, name_yend, name_q, self.name_w, self.name_regimes))
+                results_p[r] = pool.apply_async(
+                    _work,
+                    args=(
+                        self.y,
+                        x_constant,
+                        w,
+                        regi_ids,
+                        r,
+                        yend,
+                        q,
+                        robust,
+                        sig2n_k,
+                        self.name_ds,
+                        self.name_y,
+                        name_x,
+                        name_yend,
+                        name_q,
+                        self.name_w,
+                        self.name_regimes,
+                    ),
+                )
             else:
-                results_p[r] = _work(*(self.y, x_constant, w, regi_ids, r, yend, q, robust, sig2n_k,
-                                       self.name_ds, self.name_y, name_x, name_yend, name_q, self.name_w, self.name_regimes))
+                results_p[r] = _work(
+                    *(
+                        self.y,
+                        x_constant,
+                        w,
+                        regi_ids,
+                        r,
+                        yend,
+                        q,
+                        robust,
+                        sig2n_k,
+                        self.name_ds,
+                        self.name_y,
+                        name_x,
+                        name_yend,
+                        name_q,
+                        self.name_w,
+                        self.name_regimes,
+                    )
+                )
 
         self.kryd = 0
         self.kr = x_constant.shape[1] + yend.shape[1]
@@ -378,8 +486,14 @@ class TSLS_Regimes(BaseTSLS, REGI.Regimes_Frame):
             pool.join()
 
         results = {}
-        self.name_y, self.name_x, self.name_yend, self.name_q, self.name_z, self.name_h = [
-        ], [], [], [], [], []
+        (
+            self.name_y,
+            self.name_x,
+            self.name_yend,
+            self.name_q,
+            self.name_z,
+            self.name_h,
+        ) = ([], [], [], [], [], [])
         counter = 0
         for r in self.regimes_set:
             """
@@ -393,12 +507,19 @@ class TSLS_Regimes(BaseTSLS, REGI.Regimes_Frame):
             else:
                 results[r] = results_p[r].get()
 
-            self.vm[(counter * self.kr):((counter + 1) * self.kr),
-                    (counter * self.kr):((counter + 1) * self.kr)] = results[r].vm
+            self.vm[
+                (counter * self.kr) : ((counter + 1) * self.kr),
+                (counter * self.kr) : ((counter + 1) * self.kr),
+            ] = results[r].vm
             self.betas[
-                (counter * self.kr):((counter + 1) * self.kr), ] = results[r].betas
-            self.u[regi_ids[r], ] = results[r].u
-            self.predy[regi_ids[r], ] = results[r].predy
+                (counter * self.kr) : ((counter + 1) * self.kr),
+            ] = results[r].betas
+            self.u[
+                regi_ids[r],
+            ] = results[r].u
+            self.predy[
+                regi_ids[r],
+            ] = results[r].predy
             self.name_y += results[r].name_y
             self.name_x += results[r].name_x
             self.name_yend += results[r].name_yend
@@ -407,52 +528,76 @@ class TSLS_Regimes(BaseTSLS, REGI.Regimes_Frame):
             self.name_h += results[r].name_h
             counter += 1
         self.multi = results
-        self.hac_var = sphstack(x_constant[:,1:], q)
-        if robust == 'hac':
+        self.hac_var = sphstack(x_constant[:, 1:], q)
+        if robust == "hac":
             hac_multi(self, gwk)
-        if robust == 'ogmm':
+        if robust == "ogmm":
             set_warn(
-                self, "Residuals treated as homoskedastic for the purpose of diagnostics.")
+                self,
+                "Residuals treated as homoskedastic for the purpose of diagnostics.",
+            )
         self.chow = REGI.Chow(self)
         if spat_diag:
             self._get_spat_diag_props(results, regi_ids, x_constant, yend, q)
         SUMMARY.TSLS_multi(
-            reg=self, multireg=self.multi, vm=vm, spat_diag=spat_diag, regimes=True, w=w)
+            reg=self, multireg=self.multi, vm=vm, spat_diag=spat_diag, regimes=True, w=w
+        )
 
     def _get_spat_diag_props(self, results, regi_ids, x, yend, q):
         self._cache = {}
-        x = REGI.regimeX_setup(
-            x, self.regimes, [True] * x.shape[1], self.regimes_set)
-        self.z = sphstack(x, REGI.regimeX_setup(
-            yend, self.regimes, [True] * yend.shape[1], self.regimes_set))
+        x = REGI.regimeX_setup(x, self.regimes, [True] * x.shape[1], self.regimes_set)
+        self.z = sphstack(
+            x,
+            REGI.regimeX_setup(
+                yend, self.regimes, [True] * yend.shape[1], self.regimes_set
+            ),
+        )
         self.h = sphstack(
-            x, REGI.regimeX_setup(q, self.regimes, [True] * q.shape[1], self.regimes_set))
+            x,
+            REGI.regimeX_setup(q, self.regimes, [True] * q.shape[1], self.regimes_set),
+        )
         hthi = np.linalg.inv(spdot(self.h.T, self.h))
         zth = spdot(self.z.T, self.h)
         self.varb = np.linalg.inv(spdot(spdot(zth, hthi), zth.T))
 
 
-def _work(y, x, w, regi_ids, r, yend, q, robust, sig2n_k, name_ds, name_y, name_x, name_yend, name_q, name_w, name_regimes):
+def _work(
+    y,
+    x,
+    w,
+    regi_ids,
+    r,
+    yend,
+    q,
+    robust,
+    sig2n_k,
+    name_ds,
+    name_y,
+    name_x,
+    name_yend,
+    name_q,
+    name_w,
+    name_regimes,
+):
     y_r = y[regi_ids[r]]
     x_r = x[regi_ids[r]]
     yend_r = yend[regi_ids[r]]
     q_r = q[regi_ids[r]]
-    if robust == 'hac' or robust == 'ogmm':
+    if robust == "hac" or robust == "ogmm":
         robust2 = None
     else:
         robust2 = robust
-    model = BaseTSLS(
-        y_r, x_r, yend_r, q_r, robust=robust2, sig2n_k=sig2n_k)
+    model = BaseTSLS(y_r, x_r, yend_r, q_r, robust=robust2, sig2n_k=sig2n_k)
     model.title = "TWO STAGE LEAST SQUARES ESTIMATION - REGIME %s" % r
-    if robust == 'ogmm':
+    if robust == "ogmm":
         _optimal_weight(model, sig2n_k, warn=False)
     model.robust = USER.set_robust(robust)
     model.name_ds = name_ds
-    model.name_y = '%s_%s' % (str(r), name_y)
-    model.name_x = ['%s_%s' % (str(r), i) for i in name_x]
-    model.name_yend = ['%s_%s' % (str(r), i) for i in name_yend]
+    model.name_y = "%s_%s" % (str(r), name_y)
+    model.name_x = ["%s_%s" % (str(r), i) for i in name_x]
+    model.name_yend = ["%s_%s" % (str(r), i) for i in name_yend]
     model.name_z = model.name_x + model.name_yend
-    model.name_q = ['%s_%s' % (str(r), i) for i in name_q]
+    model.name_q = ["%s_%s" % (str(r), i) for i in name_q]
     model.name_h = model.name_x + model.name_q
     model.name_w = name_w
     model.name_regimes = name_regimes
@@ -486,38 +631,52 @@ def _optimal_weight(reg, sig2n_k, warn=True):
     reg.title += " (Optimal-Weighted GMM)"
     if warn:
         set_warn(
-            reg, "Residuals treated as homoskedastic for the purpose of diagnostics.")
+            reg, "Residuals treated as homoskedastic for the purpose of diagnostics."
+        )
     return
 
 
 def _test():
     import doctest
-    start_suppress = np.get_printoptions()['suppress']
+
+    start_suppress = np.get_printoptions()["suppress"]
     np.set_printoptions(suppress=True)
     doctest.testmod()
     np.set_printoptions(suppress=start_suppress)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     _test()
     import numpy as np
     import libpysal
     from libpysal.examples import load_example
 
-    nat = load_example('Natregimes')
-    db = libpysal.io.open(nat.get_path('natregimes.dbf'), 'r')
-    y_var = 'HR60'
+    nat = load_example("Natregimes")
+    db = libpysal.io.open(nat.get_path("natregimes.dbf"), "r")
+    y_var = "HR60"
     y = np.array([db.by_col(y_var)]).T
-    x_var = ['PS60', 'DV60', 'RD60']
+    x_var = ["PS60", "DV60", "RD60"]
     x = np.array([db.by_col(name) for name in x_var]).T
-    yd_var = ['UE60']
+    yd_var = ["UE60"]
     yd = np.array([db.by_col(name) for name in yd_var]).T
-    q_var = ['FP59', 'MA60']
+    q_var = ["FP59", "MA60"]
     q = np.array([db.by_col(name) for name in q_var]).T
-    r_var = 'SOUTH'
+    r_var = "SOUTH"
     regimes = db.by_col(r_var)
-    tslsr = TSLS_Regimes(y, x, yd, q, regimes, constant_regi='many', spat_diag=False, name_y=y_var, name_x=x_var,
-                         name_yend=yd_var, name_q=q_var, name_regimes=r_var, cols2regi=[
-                             False, True, True, True],
-                         sig2n_k=False)
+    tslsr = TSLS_Regimes(
+        y,
+        x,
+        yd,
+        q,
+        regimes,
+        constant_regi="many",
+        spat_diag=False,
+        name_y=y_var,
+        name_x=x_var,
+        name_yend=yd_var,
+        name_q=q_var,
+        name_regimes=r_var,
+        cols2regi=[False, True, True, True],
+        sig2n_k=False,
+    )
     print(tslsr.summary)
